{% load traces_tags %}
<!DOCTYPE html>
<html>
<head>
    <title>{% block title %}{% endblock %}</title>
</head>
<body>

{% get_view_hits as hits %}
Hits: {{ hits }}
{% block main %}{% endblock %}

</body>
</html>